@@ -24,6 +24,10 @@ pub enum DisplayError {
     CSError,
     /// The requested DataFormat is not implemented by this display interface implementation
     DataFormatNotImplemented,
+    /// Unable to assert or de-assert reset signal
+    RSError,
+    /// Attempted to write to a non-existing pixel outside the display's bounds
+    OutOfBoundsError,
 }
 
 /// DI specific data format wrapper around slices of various widths
